@@ -7,12 +7,13 @@ require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = ();
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 bootstrap Quota;
 
 use Carp;
 use POSIX qw(:errno_h);
+use strict;
 
 ##
 ##  Get block device for locally mounted file system
@@ -20,11 +21,12 @@ use POSIX qw(:errno_h);
 
 sub getdev {
   ($#_ > 0) && croak("Usage: Quota::getdev(path)");
-  my($dev) = (stat(($_[0] || ".")))[0];
+  my($target) = (($#_ == -1) ? "." : $_[0]);
+  my($dev) = (stat($target))[0];
   my($ret) = undef;
   my($fsname,$path);
  
-  if($dev && !Quota::setmntent()) {
+  if($dev && ($target ne "") && !Quota::setmntent()) {
     while(($fsname,$path) = Quota::getmntent()) {
       ($ret=$fsname, last) if ($dev == (stat($path))[0]);
     }
@@ -37,35 +39,38 @@ sub getdev {
 ##
 ##  Get "dev" argument for Quota-functions in this module
 ##  !! Not all operating systems require the same type of info as parameter
-##  !! for the quotactl call. i.e. SYS-V and SunOS wants the block device,
-##  !! Solaris the pathname of the quotas file on disk, OSF/1 any pathname
+##  !! for the quotactl call. E.g. SunOS wants the block device, but
+##  !! Solaris the pathname of the quotas file below the mount point
 ##
+
 sub getqcarg {
   ($#_ > 0) && croak("Usage: Quota::getqcarg(path)");
-  my($dev) = (stat(($_[0] || ".")))[0];
+  my($target) = (($#_ == -1) ? "." : $_[0]);
+  my($dev) = (stat($target))[0];
   my($ret) = undef;
-  my($argtyp) = getqcargtype();
+  my($argtyp,$fsupp) = (Quota::getqcargtype() =~ /([^,]*)(,.*)?/);
   my($fsname,$path,$fstyp);
 
-  if($dev && !Quota::setmntent()) {
+  if($dev && ($target ne "") && !Quota::setmntent()) {
     while(($fsname,$path,$fstyp) = Quota::getmntent()) {
       next if $fstyp =~ /^(lofs|ignore|auto.*)$/;
       if($dev == (stat($path))[0]) {
-	if($fsname !~ m#^/#) { $ret = $fsname }
-	elsif($argtyp eq "dev")  { $ret = $fsname }
-	elsif($argtyp eq "path") { $ret = "$path/quotas" }
-	elsif($argtyp eq "dev(XFS)") {
-	  if($fstyp eq "xfs") { $ret = "(XFS)$fsname"; }
-	  else { $ret = "$fsname"; }
-	}
-	else { $ret = $path }  #($argtyp eq "mntpt")
+	if($fsname =~ m#^[^/]+:/#) { $ret = $fsname }   #NFS host:/path
+	elsif($argtyp eq "dev")    { $ret = $fsname }
+	elsif($argtyp eq "qfile")  { $ret = "$path/quotas" }
+	elsif($argtyp eq "any")    { $ret = $target }
+	else                       { $ret = $path }     #($argtyp eq "mntpt")
+
+        # XFS and AFS quotas require separate access methods
+        if   (($fstyp eq "xfs") && ($fsupp =~ /XFS/)) { $ret = "(XFS)$ret"; }
+        elsif((($fstyp eq "afs") || ($fsname eq "AFS")) &&
+              ($fsupp =~ /AFS/)) { $ret = "(AFS)$target"; }
         last;
       }
     }
     $! = 0;
   }
   Quota::endmntent();
-  ##return ($_[0] || ".") if ($argtyp eq "path") && ($ret =~ m#^/#);
   $ret;
 }
 
@@ -82,6 +87,7 @@ sub strerr {
                          { $str = "No quotas on this system" }
     elsif($! == &ENODEV) { $str = "Not a standard file system" }
     elsif($! == &EPERM)  { $str = "Not privileged" }
+    elsif($! == &EACCES) { $str = "Access denied" }
     elsif($! == &ESRCH)  { $str = "No quota for this user" }
     elsif($! == &EUSERS) { $str = "Quota table overflow" }
     else { die "unknown quota error\n" }
@@ -163,6 +169,8 @@ I<$bs> and I<$is> are the soft limits, I<$bh> and I<$ih> hard limits. If the
 soft limit is exceeded, writes by this user will fail for blocks or
 inodes after I<$bt> or I<$it> is reached. These times are expressed
 as usual, i.e. in elapsed seconds since 00:00 1/Jan/1970 GMT.
+When the quota limits are not exceeded, the timestamps have no
+meaning and should be ignored.
 
 =item I<Quota::setqlim($dev, $uid, $bs,$bh, $is,$ih, $tlo)>
 
@@ -297,9 +305,9 @@ Jim Hribnak (hribnak@nucleus.com),
 David Lloyd (cclloyd@monotreme.cc.missouri.edu),
 James Shelburne (reilly@eramp.net) and
 Subhendu Ghosh (sghosh@menger.eecs.stevens-tech.edu).
-Special thanks go to Steve Nolan at bookmark.com for providing
-me with an account and hence finally allowing me to finish the
-Linux port.
+Special thanks to Steve Nolan (nolansj@bookmark.com) and
+Wolfgang Friebel (friebel@ifh.de)
+for providing me with accounts for the Linux and AIX ports.
 
 =head1 SEE ALSO
 
