@@ -1,8 +1,9 @@
 
 /*
  *   Configuration for Solaris 2.4 & 2.5.x
- *
  *   (this is for use with SYSV flavour, not /usr/bsd)
+ *
+ *   For AFS support look at the end of this file
  */
 
 /*   See hints/none.h for a complete list of options with explanations */
@@ -54,3 +55,18 @@ struct quotactl {
 #define QS_BTIME dqb_btimelimit
 #define QS_FTIME dqb_ftimelimit
 
+
+/*
+ *  If you have AFS (arla) uncomment the following define and MAKE lines
+ *  (If the SUNWspro compiler doesn't work try gcc or workshop)
+ */
+
+/* #define AFSQUOTA */
+
+/* MakeMaker parameters - do not remove!
+#MAKE AFSHOME=/products/security/athena
+#MAKE LD_RUN_PATH=$(AFSHOME)/lib
+#MAKE LDLOADLIBS=-L$(LD_RUN_PATH) -lkafs -ldes -lkrb -Wl,-R -Wl,$(LD_RUN_PATH)
+#MAKE INC=-I$(AFSHOME)/include
+#MAKE OBJ=afsquota.o
+*/
