@@ -1,5 +1,7 @@
 /*
  *   Configuration for SunOS 4.1.3
+ *
+ *   For AFS support look at the end of this file
  */
 
 /*   See hints/none.h for a complete list of options with explanations */
@@ -36,3 +38,17 @@
 #define QS_BTIME dqb_btimelimit
 #define QS_FTIME dqb_ftimelimit
 
+
+/*
+ *  If you have AFS (arla) uncomment the following define and MAKE lines
+ *  ANSI C compiler is required (SC1.0 acc or gcc)
+ */
+
+/* #define AFSQUOTA */
+
+/* MakeMaker parameters - do not remove!
+#MAKE AFSHOME=/products/security/athena
+#MAKE LDLOADLIBS=-L$(AFSHOME)/lib -lkafs -ldes -lkrb -lrpcsvc
+#MAKE INC=-U__STDC__ -DSunOS4 -I$(AFSHOME)/include
+#MAKE OBJ=afsquota.o
+*/
